### BEGIN LICENSE
# Copyright (C) 2010 Owais Lone hello@owaislone.org
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from gi.repository import Gtk
from gi.repository import GObject


#TODO: stop using **kwargs and go back to named arguments so you can pass them
# from the function to the class

class Prompt(Gtk.Dialog):
    """ A base class for some prompts - creates Ok and Cancel buttons,
    displays a title and a label.
    """

    def __init__(self, title, text):
        """Creates a Prompt
        arguments:
        title - The title for the dialog window
        text -  The string to display in the Prompts label

        """

        GObject.GObject.__init__(self)
        self.set_has_separator(False)
        content_area = self.get_content_area()
        content_area.set_border_width(5)
        self.set_default_response(Gtk.ResponseType.OK)

        self.content_box = Gtk.VBox(False, 10)
        label = Gtk.Label(label=text)
        self.content_box.pack_start(label, False, False, 5)
        content_area.pack_start(self.content_box, True, True, 0)
        self.content_box.show()
        label.show()


def warning(parent, title = "Warning", text = ""):
    """warning - displays a warning to the user, includes an appropriate icon
    and an OK button

    aguments:
    parent - a parent object, use it to bind the MessageDialog to another object
    title - a string to be the title of the dialog
    text - a string describing the warning

    returns a Gtk.DialogResponse
    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
    the user dismissed the dialogv(Gtk.ResponseType.DELETE_EVENT)

    """

    w = Alert(title, text, Gtk.MessageType.WARNING)
    response = w.run()
    w.destroy()
    return response


def error(parent, title = "ERROR", text = ""):
    """error - displays an error to the user, includes an appropriate icon
    and an OK button

    aguments:
    parent - a parent object, use it to bind the MessageDialog to another object
    title - a string to be the title of the dialog
    text - a string describing the error

    returns a Gtk.DialogResponse
    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
    the user dismissed the dialogv(Gtk.ResponseType.DELETE_EVENT)

    """

    e = Alert(parent, title, text, Gtk.MessageType.ERROR)
    response = e.run()
    e.destroy()
    return response


def info(parent, title = "Information", text = ""):
    """info - displays information to the user, includes an appropriate
    icon and an OK button

    aguments:
    parent - a parent object, use it to bind the MessageDialog to another object    
    title - a string to be the title of the dialog
    text - a string providing the information

    returns a Gtk.DialogResponse
    Gtk.ResponseType.OK means the user clicked the "OK" button, otherwise
    the user dismissed the dialogv(Gtk.ResponseType.DELETE_EVENT)

    """

    i = Alert(title, text, Gtk.MessageType.INFO)
    response = i.run()
    i.destroy()
    return response


class Alert(Gtk.MessageDialog):
    """Displays an icon, a message, and an OK button to users.
    Used by prompts.info(), prompts.warning(),
    and prompts.error() calls.

    Using
    #Display a message to the user using one of the helper functions
    prompts.<type>(parent, title, text, alert_type)
      <type> is one of the 'info', 'warning', 'error'
        
    Where:

    parent - a Parent Dialog object or self
    title - the message title, appears in the message dialog itself.
    text - additional information, appears under the title.
    alert_type - Gtk enum which sets the message type. Most used types
    are:
       Gtk.MessageType.INFO
       Gtk.MessageType.WARNING
       Gtk.MessageType.ERROR

    Extending
    An Alert is a Gtk.MessageDialog.

    """

    def __init__(self, parent, title="", text="", alert_type=Gtk.MessageType.OTHER):
        if not parent:
            parent = self
        Gtk.MessageDialog.__init__(self, parent, 0, alert_type, Gtk.ButtonsType.OK, title)
        self.format_secondary_text(text)
